"""
Identifier:     KSC-SJ4-csst_common/status.py
Name:           status.py
Description:    CSST status
Author:         Bo Zhang
Created:        2022-10-04
Modified-History:
    2022-10-04, Bo Zhang, created
    2022-10-04, Bo Zhang, added CsstStatus
    2022-10-07, Bo Zhang, added Numpydoc docstring
"""
from enum import IntEnum
from typing import Optional, Any


class CsstStatus(IntEnum):
    """
    The CSST Status class.

    This class provides a set of status which should be returned
    from each CSST L1 functional module.

    Examples
    --------
    >>> def f(num):
    >>>     if num > 0:
    >>>         return CsstStatus.PERFECT
    >>>     return CsstStatus.ERROR
    """

    PERFECT = 0
    WARNING = 1
    ERROR = 2
    # status list to be completed


class CsstResult:
    """
    Examples
    --------
    >>> CsstResult(CsstStatus.PERFECT, ["file1.fits", "file2.fits"])
    """

    def __init__(
        self,
        status: CsstStatus = CsstStatus.ERROR,
        files: Optional[list[str]] = None,
        **output: Any,
    ):
        if files is None:
            files = []
        assert isinstance(
            status, CsstStatus
        ), "`status` should be a `csst_common.CsstStatus` type objects."
        assert isinstance(
            files, list
        ), "`files` should be a list of `str` type objects."
        for _ in files:
            assert isinstance(_, str), "`files` should be a list of `str` type objects."
        self.status: CsstStatus = status
        self.files: Optional[list] = files
        self.output: dict = output

    def __repr__(self):
        return f""" <CsstResult status={self.status}>
 - files: {self.files}
 - output: {self.output} \n
"""
